@@ -27,6 +27,18 @@ sub doInventory {
     my $caption;
     my $serialnumber;
 
+    my $errorCorrection;
+    foreach (@dmidecode) {
+        if (/dmi type 16,/i) {
+            $flag = 1;
+        } elsif ($flag && /^Error Correction Type\s*:\s*(.+)/i) {
+            $errorCorrection = $1;
+        } elsif ($flag && /^\s*$/) {
+            last;
+        }
+    }
+
+    $flag = 0;
     foreach (@dmidecode) {
 
         if (/dmi type 17,/i) { # begining of Memory Device section
@@ -35,15 +47,20 @@ sub doInventory {
         } elsif ($flag && /^$/) { # end of section
             $flag = 0;
 
-            $inventory->addMemory({
-                CAPACITY => $capacity,
-                DESCRIPTION => $description,
-                CAPTION => $caption,
-                SPEED => $speed,
-                TYPE => $type,
-                NUMSLOTS => $numslot,
-                SERIALNUMBER => $serialnumber,
-            });
+            $description .= " ($errorCorrection)" if $errorCorrection;
+
+            if ($type !~ /Flash/i) {
+                $inventory->addMemory({
+                    CAPACITY => $capacity,
+                    DESCRIPTION => $description,
+                    CAPTION => $caption,
+                    SPEED => $speed,
+                    TYPE => $type,
+                    NUMSLOTS => $numslot,
+                    SERIALNUMBER => $serialnumber,
+                    MEMORYCORRECTION => $errorCorrection
+                });
+            }
 
             $capacity = $description = $caption = $type = $type = $speed = $serialnumber = undef;
         } elsif ($flag) { # in the section
