@@ -13,7 +13,7 @@ package FusionInventory::Agent::Task::Inventory::OS::Generic::Screen;
 
 #     You should have received a copy of the GNU General Public License
 #     along with this program; if not, write to the Free Software
-#     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 # Some part come from Mandriva's (great) monitor-edid
 # http://svn.mandriva.com/cgi-bin/viewvc.cgi/soft/monitor-edid/trunk/
@@ -32,6 +32,91 @@ sub isInventoryEnabled {
         can_run("get-edid");
 }
 
+sub getScreensFromWindows {
+    my ($logger) = @_;
+
+    my $devices = {};
+    my $Registry;
+    eval {
+        require FusionInventory::Agent::Tools::Win32;
+        require FusionInventory::Agent::Task::Inventory::OS::Win32;
+        require Win32::TieRegistry;
+        Win32::TieRegistry->import(
+                Delimiter   => '/',
+                ArrayValues => 0,
+                TiedRef     => \$Registry
+                );
+    };
+    if ($EVAL_ERROR) {
+        print "Failed to load Win32::OLE and Win32::TieRegistry\n";
+        return;
+    }
+
+    use constant wbemFlagReturnImmediately => 0x10;
+    use constant wbemFlagForwardOnly => 0x20;
+
+# Vista and upper, able to get the second screen  
+    my $WMIServices = Win32::OLE->GetObject(
+            "winmgmts:{impersonationLevel=impersonate,authenticationLevel=Pkt}!//./root/wmi" );
+
+    foreach my $properties ( Win32::OLE::in( $WMIServices->InstancesOf(
+                    "WMIMonitorID" ) ) )
+    {
+
+        next unless $properties->{InstanceName};
+        my $PNPDeviceID = $properties->{InstanceName};
+        $PNPDeviceID =~ s/_\d+//;
+        $devices->{lc($PNPDeviceID)} = {};
+    }
+
+# The generic Win32_DesktopMonitor class, the second screen will be missing
+    foreach my $objItem (FusionInventory::Agent::Task::Inventory::OS::Win32::getWmiProperties('Win32_DesktopMonitor', qw/
+                Caption PNPDeviceID Availability MonitorType MonitorManufacturer
+                /)) {
+
+        next unless $objItem->{"Availability"};
+        next unless $objItem->{"PNPDeviceID"};
+        next unless $objItem->{"Availability"} == 3;
+        my $name = $objItem->{"Caption"};
+
+        $devices->{lc($objItem->{"PNPDeviceID"})} = { name => $name, type => $objItem->{MonitorType}, manufacturer => $objItem->{MonitorManufacturer}, caption => $objItem->{Caption} };
+
+    }
+
+    my @ret;
+    foreach my $PNPDeviceID (keys %{$devices}) {
+
+
+        my $machKey;
+        {
+            my $KEY_WOW64_64KEY = 0x100;
+
+            my $access;
+
+            if (FusionInventory::Agent::Tools::Win32::is64bit()) {
+                $access = Win32::TieRegistry::KEY_READ() | $KEY_WOW64_64KEY;
+            } else {
+                $access = Win32::TieRegistry::KEY_READ();
+            }
+
+# Win32-specifics constants can not be loaded on non-Windows OS
+            no strict 'subs';
+            $machKey = $Registry->Open('LMachine', {
+                    Access => $access
+                    } ) or $logger->fault("Can't open HKEY_LOCAL_MACHINE key: $EXTENDED_OS_ERROR");
+
+        }
+
+        $devices->{$PNPDeviceID}{edid} =
+            $machKey->{"SYSTEM/CurrentControlSet/Enum/".$PNPDeviceID."/Device Parameters/EDID"} || '';
+        $devices->{$PNPDeviceID}{edid} =~ s/^\s+$//;
+
+        push @ret, $devices->{$PNPDeviceID};
+    }
+    return @ret;
+
+}
+
 sub getScreens {
     my ($logger) = @_;
 
@@ -39,49 +124,8 @@ sub getScreens {
 
 
     if ($OSNAME eq 'MSWin32') {
-        my $Registry;
-        eval {
-            require FusionInventory::Agent::Task::Inventory::OS::Win32;
-            require Win32::TieRegistry;
-            Win32::TieRegistry->import(
-                Delimiter   => '/',
-                ArrayValues => 0,
-                TiedRef     => \$Registry
-            );
-        };
-        if ($EVAL_ERROR) {
-            print "Failed to load Win32::OLE and Win32::TieRegistry\n";
-            return;
-        }
-
-#        use constant wbemFlagReturnImmediately => 0x10;
-#        use constant wbemFlagForwardOnly => 0x20;
-
-#        my $objWMIService = Win32::OLE->GetObject("winmgmts:\\\\.\\root\\CIMV2") or $logger->fault("WMI connection failed.\n");
-#        my $colItems = $objWMIService->ExecQuery("SELECT * FROM Win32_DesktopMonitor", "WQL",
-#                wbemFlagReturnImmediately | wbemFlagForwardOnly);
-        foreach my $objItem (FusionInventory::Agent::Task::Inventory::OS::Win32::getWmiProperties('Win32_DesktopMonitor', qw/
-            Caption MonitorManufacturer MonitorType PNPDeviceID
-        /)) {
-
-            next unless $objItem->{"PNPDeviceID"};
-            my $name = $objItem->{"Caption"};
-
-            my $machKey;
-            {
-                # Win32-specifics constants can not be loaded on non-Windows OS
-                no strict 'subs';
-                $machKey = $Registry->Open('LMachine', {
-                    Access => Win32::TieRegistry::KEY_READ
-                } ) or $logger->fault("Can't open HKEY_LOCAL_MACHINE key: $EXTENDED_OS_ERROR");
-            }
-
-            my $edid =
-                $machKey->{"SYSTEM/CurrentControlSet/Enum/$objItem->{PNPDeviceID}/Device Parameters/EDID"} || '';
-            $edid =~ s/^\s+$//;
-
-            push @raw_edid, { name => $name, edid => $edid, type => $objItem->{MonitorType}, manufacturer => $objItem->{MonitorManufacturer}, caption => $objItem->{Caption} };
-        }
+ 
+        @raw_edid = getScreensFromWindows($logger);
 
     } else {
 
@@ -559,6 +603,7 @@ sub print_edid {
 sub _getManifacturerFromCode {
     my $code = shift;
     my $h = {
+        "ACR" => "Acer America Corp.",
         "ACT" => "Targa",
         "ADI" => "ADI Corporation http://www.adi.com.tw",
         "AOC" => "AOC International (USA) Ltd.",
@@ -576,6 +621,7 @@ sub _getManifacturerFromCode {
         "DWE" => "Daewoo Telecom Ltd",
         "ECS" => "ELITEGROUP Computer Systems",
         "EIZ" => "EIZO",
+        "EPI" => "Envision Peripherals, Inc.",
         "FCM" => "Funai Electric Company of Taiwan",
         "FUS" => "Fujitsu Siemens",
         "GSM" => "LG Electronics Inc. (GoldStar Technology, Inc.)",
@@ -590,6 +636,7 @@ sub _getManifacturerFromCode {
         "IVM" => "Idek Iiyama North America, Inc.",
         "KDS" => "KDS USA",
         "KFC" => "KFC Computek",
+        "LEN" => "Lenovo",
         "LGD" => "LG Display",
         "LKM" => "ADLAS / AZALEA",
         "LNK" => "LINK Technologies, Inc.",
@@ -625,11 +672,23 @@ sub _getManifacturerFromCode {
         "VSC" => "ViewSonic Corporation",
         "WTC" => "Wen Technology",
         "ZCM" => "Zenith Data Systems",
-        "___" => "Targa"
+        "___" => "Targa",
+        "BNQ" => "BenQ Corporation",
+        "LPL" => "LG Philips",
+        "PCK" => "Daewoo",
+        "NVD" => "Nvidia", #Nvidia
+        "HIQ" => "Hyundai ImageQuest",
+        "BMM" => "BMM",
+        "AMW" => "AMW",
+        "IFS" => "InFocus",
+        "BOE" => "BOE Display Technology",
+        "IQT" => "Hyundai",
+
+
     };
 
     return $h->{$code} if (exists ($h->{$code}) && $h->{$code});
-    return "Unknown manufacturer code ".$code;
+    return $code;
 }
 
 sub sqr { $_[0] * $_[0] }
