@@ -49,7 +49,7 @@ sub getFromDF {
 
     my %months = (
         Jan => 1,
-        Fev => 2,
+        Feb => 2,
         Mar => 3,
         Apr => 4,
         May => 5,
