@@ -13,6 +13,7 @@ sub doInventory {
     my $params = shift;
     my $inventory = $params->{inventory};
 
+    my $KernelVersion;
     my $OSName;
     my $OSComment;
     my $OSVersion;
@@ -42,6 +43,8 @@ sub doInventory {
         chomp($OSVersion=`uname -r`);			
     }
 
+    chomp($KernelVersion=`uname -r`);
+
     # add the uname -v as the comment, not really needed, but extra info never hurt
     chomp($OSComment=`uname -v`);
     $inventory->setHardware({
@@ -49,6 +52,13 @@ sub doInventory {
         OSCOMMENTS => $OSComment,
         OSVERSION  => $OSVersion,
     });
+
+    $inventory->setOperatingSystem({
+        NAME                 => "MacOSX",
+        VERSION              => $OSVersion,
+        KERNEL_VERSION       => $KernelVersion,
+        FULL_NAME            => $OSName
+    });
 }
 
 
