@@ -1,5 +1,7 @@
 package FusionInventory::Agent::Task::Inventory::OS::MacOS::Printers;
+
 use strict;
+use warnings;
 
 use constant DATATYPE => 'SPPrintersDataType';
 
@@ -12,12 +14,27 @@ sub isInventoryEnabled {
 sub doInventory {
     my $params = shift;
     my $inventory = $params->{inventory};
+    my $config = $params->{config};
+
+    return if $config->{'no-printer'};
 
     my $pro = Mac::SysProfile->new();
     my $h = $pro->gettype(DATATYPE());
     return(undef) unless(ref($h) eq 'HASH');
 
     foreach my $printer (keys %$h){
+        if ($printer && (
+            $printer =~ /list is empty/
+            ||
+            $printer =~ /^Status/
+            ||
+            $printer =~ /^CUPS Version/
+            )            ) {
+#http://forge.fusioninventory.org/issues/169
+#https://bugs.launchpad.net/bugs/901570
+                next;
+        }
+
         $inventory->addPrinter({
                 NAME    => $printer,
                 DRIVER  => $h->{$printer}->{'PPD'},
