@@ -6,7 +6,12 @@ use warnings;
 use constant wbemFlagReturnImmediately => 0x10;
 use constant wbemFlagForwardOnly => 0x20;
 
-use Encode qw(encode);
+use Win32::API;
+# Kernel32.dll is used more or less everywhere.
+# Without this, Win32::API will release the DLL even
+# if it's a very bad idea
+*Win32::API::DESTROY = sub {};
+use Encode qw(encode decode);
 use English qw(-no_match_vars);
 use Win32::OLE::Variant;
 use Win32::TieRegistry (
@@ -14,6 +19,7 @@ use Win32::TieRegistry (
     ArrayValues => 0,
     qw/KEY_READ/
 );
+use FusionInventory::Agent::Tools::Win32;
 
 use FusionInventory::Agent::Task::Inventory::OS::Win32;
 
@@ -23,21 +29,29 @@ sub KEY_WOW64_32KEY () { 0x0200}
 #http://www.perlmonks.org/?node_id=497616
 # Thanks William Gannon && Charles Clarkson
 
+# TODO: FusionInventory::Agent::Tools::Win32::getValueFromRegistry()
+sub _getValueFromRegistry {
+    my ($logger, $path) = @_;
+
+    my $key;
+    if (is64bit()) {
+        my $machKey = $Registry->Open('LMachine', { Access=> KEY_READ()|KEY_WOW64_64KEY() } )
+	    or $logger->error("Can't open HKEY_LOCAL_MACHINE: $EXTENDED_OS_ERROR");
+	$key = $machKey->{$path};
+
+    } else {
+	my $machKey = $Registry->Open('LMachine', { Access=> KEY_READ() } )
+            or $logger->error("Can't open HKEY_LOCAL_MACHINE: $EXTENDED_OS_ERROR");
+        $key = $machKey->{$path};
+    }
+
+    return $key
+}
 
 sub getXPkey {
     my ($logger) = @_;
 
-    my $machKey = $Registry->Open('LMachine', { Access=> KEY_READ() } )
-    or $logger->fault("Can't open HKEY_LOCAL_MACHINE: $EXTENDED_OS_ERROR");
-    my $key     =
-    $machKey->{'Software/Microsoft/Windows NT/CurrentVersion/DigitalProductId'};
-
-    if (!$key) { # 64bit OS?
-        $machKey = $Registry->Open('LMachine', { Access=> KEY_READ()|KEY_WOW64_64KEY() } )
-            or $logger->fault("Can't open HKEY_LOCAL_MACHINE: $EXTENDED_OS_ERROR");
-        $key     =
-        $machKey->{'Software/Microsoft/Windows NT/CurrentVersion/DigitalProductId'};
-    }
+    my $key = _getValueFromRegistry($logger, 'Software/Microsoft/Windows NT/CurrentVersion/DigitalProductId');
     return unless $key;
     my @encoded = ( unpack 'C*', $key )[ reverse 52 .. 66 ];
 
@@ -97,6 +111,8 @@ sub doInventory {
         /)) {
 
         my $key = getXPkey($logger); 
+        my $description = encodeFromRegistry(_getValueFromRegistry($logger,
+'SYSTEM/CurrentControlSet/Services/lanmanserver/Parameters/srvcomment'));
 
         $inventory->setHardware({
             WINLANG => $Properties->{OSLanguage},
@@ -108,28 +124,54 @@ sub doInventory {
             WINOWNER => $Properties->{RegistredUser},
             OSCOMMENTS => $Properties->{CSDVersion},
             SWAP => int(($Properties->{TotalSwapSpaceSize}||0)/(1024*1024)),
+            DESCRIPTION => $description,
         });
+
+        $inventory->setOperatingSystem({
+            NAME                 => "Windows",
+#            VERSION              => $OSVersion,
+            KERNEL_VERSION       => $Properties->{Version},
+            FULL_NAME            => $Properties->{Caption},
+            SERVICE_PACK         => $Properties->{CSDVersion}
+        });
+    }
+
+
+
+    my $GetComputerName = new Win32::API("kernel32", "GetComputerNameExW", ["I", "P", "P"],
+            "N");
+    my $lpBuffer = "\x00" x 1024;
+    my $N=1024;#pack ("c4", 160,0,0,0);
+
+    my $return = $GetComputerName->Call(3, $lpBuffer,$N);
+
+# GetComputerNameExW returns the string in UTF16, we have to change it
+# to UTF8
+    my $name = encode("UTF-8", substr(decode("UCS-2le", $lpBuffer),0,ord $N));
+    my $domain;
+    if ($name =~ s/^([^\.]+)\.(.+)/$1/) {
+        $domain = $2;
     }
 
     foreach my $Properties (getWmiProperties('Win32_ComputerSystem', qw/
         Name Domain Workgroup UserName PrimaryOwnerName TotalPhysicalMemory
     /)) {
 
-        my $workgroup = $Properties->{Domain} || $Properties->{Workgroup};
-        my $userdomain;
-#        my $userid;
-#        my @tmp = split(/\\/, $Properties->{UserName});
-#        $userdomain = $tmp[0];
-#        $userid = $tmp[1];
+        my $workgroup = $Properties->{Domain};
+        $workgroup = $Properties->{Workgroup} unless $workgroup;
+        $workgroup = $domain unless $workgroup;
+
         my $winowner = $Properties->{PrimaryOwnerName};
 
         #$inventory->addUser({ LOGIN => encode('UTF-8', $Properties->{UserName}) });
+        $name = $Properties->{Name} unless $name;
+        $name = $ENV{COMPUTERNAME} unless $name;
+
         $inventory->setHardware({
             MEMORY => int(($Properties->{TotalPhysicalMemory}||0)/(1024*1024)),
-            USERDOMAIN => $userdomain,
             WORKGROUP => $workgroup,
             WINOWNER => $winowner,
-            NAME => $Properties->{Name},
+            NAME => $name,
         });
     }
 
