@@ -74,6 +74,10 @@ sub new {
     $self->{h}{CONTENT}{BATTERIES} = [];
     $self->{h}{CONTENT}{ANTIVIRUS} = [];
     $self->{h}{CONTENT}{VERSIONCLIENT} = ['FusionInventory-Agent_v'.$FusionInventory::Agent::VERSION];
+    $self->{h}{CONTENT}{LOGICAL_VOLUMES} = [];
+    $self->{h}{CONTENT}{PHYSICAL_VOLUMES} = [];
+    $self->{h}{CONTENT}{VOLUME_GROUPS} = [];
+
 
     # Is the XML centent initialised?
     $self->{isInitialised} = undef;
@@ -345,6 +349,7 @@ sub addMemory {
         TYPE
         DESCRIPTION
         NUMSLOTS
+        MEMORYCORRECTION
     /;
 
     $self->_addEntry({
@@ -611,7 +616,7 @@ sub setHardware {
         PROCESSORT NAME PROCESSORS SWAP ETIME TYPE OSNAME IPADDR WORKGROUP
         DESCRIPTION MEMORY UUID DNS LASTLOGGEDUSER USERDOMAIN
         DATELASTLOGGEDUSER DEFAULTGATEWAY VMSYSTEM WINOWNER WINPRODID
-        WINPRODKEY WINCOMPANY WINLANG/) {
+        WINPRODKEY WINCOMPANY WINLANG CHASSIS_TYPE/) {
 # WINLANG: Windows Language, see MSDN Win32_OperatingSystem documentation
         if (exists $args->{$key}) {
             if ($key eq 'PROCESSORS' && !$nonDeprecated) {
@@ -627,6 +632,32 @@ sub setHardware {
     }
 }
 
+=item setOperatingSystem()
+
+Save global information regarding the operating system.
+
+=cut
+sub setOperatingSystem {
+    my ($self, $args) = @_;
+
+    my $logger = $self->{logger};
+
+    foreach my $key (qw/
+                        KERNEL_NAME
+                        KERNEL_VERSION
+                        NAME
+                        VERSION
+                        FULL_NAME
+                        SERVICE_PACK
+                     /) {
+
+        next unless exists $args->{$key};
+
+        my $string = $self->_encode({ string => $args->{$key} });
+        $self->{h}{'CONTENT'}{'OPERATINGSYSTEM'}{$key}[0] = $string;
+    }
+}
+
 =item setBios()
 
 Set BIOS informations.
@@ -860,6 +891,7 @@ sub addInput {
         'field' => \@fields,
         'sectionName' => 'INPUTS',
         'values' => $args,
+        'noDuplicated' => 1
     });
 }
 
@@ -968,6 +1000,60 @@ sub addAntiVirus {
     });
 }
 
+=item addLogicalVolume()
+
+Registered LVM Logical Volume
+
+=cut
+sub addLogicalVolume {
+    my ($self, $args) = @_;
+
+    my @fields = qw/LV_NAME VG_NAME ATTR SIZE LV_UUID SEG_COUNT/;
+
+    $self->_addEntry({
+        'field' => \@fields,
+        'sectionName' => 'LOGICAL_VOLUMES',
+        'values' => $args,
+        'noDuplicated' => 1
+    });
+}
+
+=item addPhysicalVolume()
+
+Registered LVM Physical Volume
+
+=cut
+sub addPhysicalVolume {
+    my ($self, $args) = @_;
+
+    my @fields = qw/DEVICE PV_NAME PV_PE_COUNT PV_UUID FORMAT ATTR SIZE FREE PE_SIZE/;
+
+    $self->_addEntry({
+        'field' => \@fields,
+        'sectionName' => 'PHYSICAL_VOLUMES',
+        'values' => $args,
+        'noDuplicated' => 1
+    });
+}
+
+=item addVolumeGroup()
+
+Registered LVM Volume Group
+
+=cut
+sub addVolumeGroup {
+    my ($self, $args) = @_;
+
+    my @fields = qw/VG_NAME PV_COUNT LV_COUNT ATTR SIZE FREE VG_UUID VG_EXTENT_SIZE/;
+
+    $self->_addEntry({
+        'field' => \@fields,
+        'sectionName' => 'VOLUME_GROUPS',
+        'values' => $args,
+        'noDuplicated' => 1
+    });
+}
+
 
 =item setAccessLog()
 
@@ -1093,9 +1179,9 @@ sub writeXML {
     my $config = $self->{config};
     my $target = $self->{target};
 
-    if ($target->{path} =~ /^$/) {
-        $logger->fault ('local path unititalised!');
-    }
+#    if ($target->{path} =~ /^$/) {
+#        $logger->fault ('local path unititalised!');
+#    }
 
     $self->initialise();
 
@@ -1127,9 +1213,9 @@ sub writeHTML {
     my $config = $self->{config};
     my $target = $self->{target};
 
-    if ($target->{path} =~ /^$/) {
-        $logger->fault ('local path unititalised!');
-    }
+#    if ($target->{path} =~ /^$/) {
+#        $logger->fault ('local path unititalised!');
+#    }
 
     $self->initialise();
 
@@ -1252,9 +1338,9 @@ sub processChecksum {
     );
     # TODO CPUS is not in the list
 
-    if (!$self->{target}->{vardir}) {
-        $logger->fault ("vardir uninitialised!");
-    }
+#    if (!$self->{target}->{vardir}) {
+#        $logger->fault ("vardir uninitialised!");
+#    }
 
     my $checksum = 0;
 
@@ -1438,6 +1524,10 @@ Motherboard model
 
 The optional asset tag for this machine.
 
+=item TYPE
+
+depcreated, replace by HARDWARE/CHASSIS_TYPE
+
 =back
 
 =head2 CONTROLLERS
@@ -1622,6 +1712,10 @@ should use the USERS section instead.
 
 =item OSVERSION
 
+Version number of the operating system. This field will be deprecated in the
+future, please use OPERATINGSYSTEM/VERSION or OPERATINGSYSTEM/KERNEL_VERSION
+instead.
+
 =item PROCESSORN
 
 =item OSCOMMENTS
@@ -1654,6 +1748,10 @@ The time needed to run the inventory on the agent side.
 
 =item OSNAME
 
+Full name of the operating system as reported by itself. This field will be
+deprecated in the future, please use OPERATINGSYSTEM/NAME or
+OPERATINGSYSTEM/FULL_NAME instead.
+
 =item IPADDR
 
 =item WORKGROUP
@@ -1684,9 +1782,37 @@ This field is deprecated, you should use the USERS section instead.
 
 =item VMSYSTEM
 
-The virtualization technologie used if the machine is a virtual machine.
+The virtualization technology used if the machine is a virtual machine.
 
-Can by: Physical (default), Xen, VirtualBox, Virtual Machine, VMware, QEMU, SolarisZone
+Can be:
+
+=over 5
+
+=item Physical: (default)
+
+=item Xen
+
+=item VirtualBox
+
+=item Virtual Machine: Generic if it's not possible to correctly identify the solution
+
+=item VMware: ESX, ESXi, server, etc
+
+=item QEMU
+
+=item SolarisZone
+
+=item VServer
+
+=item OpenVZ
+
+=item BSDJail
+
+=item Parallels
+
+=item Hyper-V
+
+=back
 
 =item WINOWNER
 
@@ -1698,6 +1824,47 @@ Can by: Physical (default), Xen, VirtualBox, Virtual Machine, VMware, QEMU, Sola
 
 =item WINLANG
 
+=item CHASSIS_TYPE
+
+The computer chassis format (e.g: Notebook, Laptop, Server, etc)
+
+=head2 OPERATINGSYSTEM
+
+=over 4
+
+=item KERNEL_NAME
+
+The name of the kernel used by this operating system, e.g freebsd, linux, hpux,
+win32, etc (linux for android).
+
+=item KERNEL_VERSION
+
+Version of the operating system's kernel, e.g 2.6.32 for Linux, 5.2.x.y on
+Windows Server 2003, etc.
+
+=item NAME
+
+Name of the Operating System ("Distributor ID" in LSB terms), e.g Debian,
+Ubuntu, CentOS, SUSE LINUX, Windows, MacOSX, FreeBSD, AIX, Android, etc.
+
+=item VERSION
+
+Version of the operating system distribution ("Release" in LSB terms), e.g 11.04
+on Ubuntu natty, 5.0.8 on Debian Lenny, 5.4 on CentOS 5.4, 2003 for Windows
+Server 2003, etc.
+
+=item FULL_NAME
+
+Full name of the operating system as reported by itself, e.g "Debian GNU/Linux
+unstable (sid)" or "Microsoft(R) Windows(R) Server 2003, Enterprise Edition
+x64". This is also contained in the HARDWARE/OSNAME field which will be
+deprecated in the future.
+
+=item SERVICE_PACK
+
+The Service Pack level reported by the operating system. This field is only
+present on systems which use this notion.
+
 =back
 
 =head2 MONITORS
@@ -2239,3 +2406,106 @@ Unique ID
 1 if the antivirus is up to date.
 
 =item VERSION
+
+=back
+
+=head2 LOGICAL_VOLUMES
+
+A LVM Logical Volume
+
+=over 4
+
+=item LV_NAME
+
+The logical volume name.
+
+=item LV_UUID
+
+The logical volume UUID.
+
+=item ATTR
+
+The special attribue used on this volume (e.g: a-)
+
+=item SIZE
+
+The size of the volume on MB.
+
+=item VG_UUID
+
+The volume group UUID.
+
+=back
+
+=head2 PHYSICAL_VOLUMES
+
+=over 4
+
+=item DEVICE
+
+The device name. Eg.: /dev/sda1 on Linux.
+
+=item PV_NAME
+
+The physical device name.
+
+=item FORMAT
+
+The format. E.g: lvm2.
+
+=item ATTR
+
+The LVM attribue in use for this phyisical device.
+
+=item SIZE
+
+The size in MB.
+
+=item PV_UUID
+
+The UUID.
+
+=item PV_PE_COUNT
+
+Item PV_PE_COUNT
+
+
+=item PE_SIZE
+
+Item PE_SIZE
+
+=back
+
+=head2 VOLUME_GROUPS
+
+A LVM Volume group.
+
+=over 4
+
+=item VG_NAME
+
+The name of the volume group.
+
+=item PV_COUNT
+
+=item LV_COUNT
+
+=item ATTR
+
+The volume group LVM attribue.
+
+=item SIZE
+
+The size.
+
+=item FREE
+
+The free space.
+
+=item VG_UUID
+
+The volume group UUID
+
+=item VG_EXTENT_SIZE
+
+
